@@ -2,9 +2,9 @@ from urllib.request import getproxies
 
 from feeluown.app import App
 
-__alias__ = 'ytmusic'
-__version__ = '0.3.0'
-__desc__ = 'YouTube Music plugin'
+__alias__ = "ytmusic"
+__version__ = "0.3.0"
+__desc__ = "YouTube Music plugin"
 
 
 ui_mgr = None
@@ -12,8 +12,8 @@ ui_mgr = None
 
 def init_config(config):
     # For example: http://127.0.0.1:7890. This will be used in API and media accessing.
-    config.deffield('HTTP_PROXY', type_=str, default='', desc='YouTube Music HTTP proxy')
-    config.deffield('HTTP_TIMEOUT', type_=int, default=2, desc='HTTP requests timeout')
+    config.deffield("HTTP_PROXY", type_=str, default="", desc="YouTube Music HTTP proxy")
+    config.deffield("HTTP_TIMEOUT", type_=int, default=2, desc="HTTP requests timeout")
 
 
 def enable(app: App):
@@ -23,7 +23,7 @@ def enable(app: App):
 
     # Use system http proxy by default.
     sys_proxies = getproxies()
-    sys_http_proxy = sys_proxies.get('http')
+    sys_http_proxy = sys_proxies.get("http")
     config_http_proxy = app.config.ytmusic.HTTP_PROXY
     if not config_http_proxy and sys_http_proxy:
         config_http_proxy = sys_http_proxy
@@ -32,14 +32,16 @@ def enable(app: App):
     provider.setup_http_timeout(app.config.ytmusic.HTTP_TIMEOUT)
     app.library.register(provider)
     if app.mode & app.GuiMode:
-        from fuo_ytmusic.ui import YtmusicUiManager
-        ui_mgr = ui_mgr or YtmusicUiManager(app)
+        from .provider_ui import ProviderUI
+
+        provider_ui = ProviderUI(app)
+        app.pvd_ui_mgr.register(provider_ui)
 
 
 def disable(app: App):
     global ui_mgr
 
-    provider = app.library.get('ytmusic')
+    provider = app.library.get("ytmusic")
     if provider is not None:
         app.library.deregister(provider)
     ui_mgr = None
